@@ -25,7 +25,7 @@ source("helper.R")
 ## library("spam", lib.loc = "../../../lib/")
 
 
-context("test-spamlistd.R")
+context("test-spamlist.R")
 
 
 ########
